@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.1.7';
+our $VERSION = '0.1.8';
 
 1;
 
@@ -444,7 +444,7 @@ For example:
 
     $ sparrow task show system disk-health
 
-Alternative way to configure sparrow task is to load configuration from yaml file I<during> task run:
+Alternative way to configure sparrow task is to load configuration from yaml/json file I<during> task run:
 
     $ cat disk.yml
     
@@ -452,9 +452,17 @@ Alternative way to configure sparrow task is to load configuration from yaml fil
     threshold: 80
     
     $ sparrow task run system disk --yaml disk.yml
+    
+    $ cat disk.json
+    
+    {
+      "threshold": 80
+    }
+    
+    $ sparrow task run system disk --json disk.json
 
 While C<sparrow task ini/load_ini> command saves task configuration and makes it persistent,
-C<sparrow task run --yaml> command applies plugin configuration only for runtime and won't save it after plugin execution.
+C<sparrow task run --yaml|--json> command applies plugin configuration only for runtime and won't save it after plugin execution.
 
 For common usage, when user runs tasks manually first approach is more convenient, 
 while the second one is a I<way automatic>, when tasks configurations are kept as yaml files
