@@ -173,6 +173,9 @@ sub task_run {
     if ($options=~/--yaml\s+(\S+)/){
       my $path = $1;
       $cmd.=" --yaml $path";
+    }elsif ($options=~/--json\s+(\S+)/){
+      my $path = $1;
+      $cmd.=" --json $path";
     }else{
       my $path = sparrow_root."/projects/$project/tasks/$tid/suite.ini";
       $cmd.=" --ini $path" if -f $path;
@@ -184,7 +187,8 @@ sub task_run {
         exec "( $cmd 1>$repo_file 2>\&1 && rm $repo_file  )  || ( cat $repo_file ; rm -v $repo_file; exit 1; )";
     } else {
         $cmd.=" $options";
-        print "# $cmd\n\n";
+        print map {"# $_\n"} split /&&\s+/, $cmd;
+        print "\n";
         exec $cmd;
     }
 
